@@ -12,7 +12,8 @@ NULL
 
 #' @title julia_setup
 #'
-#' @description Checks installation of Julia and install the needed packages. May take little time to run.Only run the first time you use Jflimo.
+#' @description Checks installation of Julia and install the needed packages.
+#' May take little time to run.Only run the first time you use Jflimo.
 #'
 #' @return Boolean. True if correct setup, False else.
 #'
@@ -35,7 +36,8 @@ julia_setup <- function(){
     return(TRUE)
   }
   else {
-    warning("FAILURE : Uncomplete Julia setup - See JuliaConnectoR's documentation")
+    warning("FAILURE :
+            Uncomplete Julia setup - See JuliaConnectoR's documentation")
     return(FALSE)
     }
 }
@@ -66,7 +68,9 @@ julia_load <- function(){
     return(TRUE)
   },
   error=function(cond) {
-    warning("FAILURE : You should run flimo.julia_setup() once to complete installation and reload flimo.")
+    warning("FAILURE :
+            You should run flimo.julia_setup() once
+            to complete installation and reload flimo.")
     return(FALSE)
   }
   )
@@ -76,20 +80,25 @@ julia_load <- function(){
 
 #' @title flimobjective
 #'
-#' @description Computes the summary statistics between simulations w.r.t. Theta and data. This function is to be minimized by flimoptim.
+#' @description Computes the summary statistics between simulations w.r.t.
+#' Theta and data. This function is to be minimized by flimoptim.
 #'
 #' @param Theta 1D array. parameters for the simulations.
 #' @param quantiles 2D array containing values following U(0,1).
 #' Row number = number of simulations.
 #' Column number = number of random variables to draw in one simulation.
 #' @param data 1D array containing the observations.
-#' @param sumstats Function computing the distance between simulations and data of form sumstats(simulations, data) where simulations : 2D array and data : 1D array.
+#' @param sumstats Function computing the distance between simulations and data
+#' of form sumstats(simulations, data) where
+#' simulations : 2D array and data : 1D array.
 #' ncol(simulations) = length(data) mandatory.
 #' @param simulatorQ Function of type simulatorQ(Theta, quantiles)
-#' where Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
+#' where Theta is the parameter set for the simulations
+#' and quantiles are drawn in U(0,1).
 #' See README for details.
 #'
-#' @return Numeric value. Distance between summary statistics of data and simulations w.r.t. Theta.
+#' @return Numeric value. Distance between summary statistics of data
+#' and simulations w.r.t. Theta.
 #'
 #' @examples
 #'
@@ -123,53 +132,95 @@ flimobjective <- function(Theta, quantiles, data, sumstats, simulatorQ){
 
 #' @title flimoptim
 #'
-#' @description Computes several parameter inferences with R optimizer or Julia optimizer in a full Julia mode.
+#' @description Computes several parameter inferences with R optimizer or
+#' Julia optimizer in a full Julia mode.
 #' In R mode (default) : L-BFGS-B optimization.
-#' In Julia mode : either IPNewton with or without Automatic Differentation or Brent optimization.
+#' In Julia mode : either IPNewton with or without Automatic Differentiation
+#' or Brent optimization.
 #'
 #' @param data 1D array containing the observations.
-#' @param ndraw Integer. Number of random variables to draw for one simulation of the model.
-#' @param sumstats Summary statistics to measure distance between simulations and data.
-#' In R mode : R function of type sumstats(simulations, data) where simulations : 2D array and data : 1D array.
+#' @param ndraw Integer. Number of random variables to draw
+#' for one simulation of the model.
+#' @param sumstats Summary statistics to measure distance
+#' between simulations and data.
+#' In R mode : R function of type sumstats(simulations, data)
+#' where simulations : 2D array and data : 1D array.
 #' ncol(simulations) = length(data) mandatory.
-#' In Julia mode : a string containing the script of the Julia function sumstats(simulations, data).
+#' In Julia mode : a string containing the script of the Julia function
+#' sumstats(simulations, data).
 #' The name "sumstats" is mandatory.
-#' @param simulatorQ Simulator of the stochastic process with fixed quantiles (see Readme).
+#' @param simulatorQ Simulator of the stochastic process with fixed quantiles
+#' (see README).
 #  Either an R function of type simulatorQ(Theta, quantiles) (in mode "R")
-#' or a string (in mode "Julia") containing the script of the Julia function simulatorQ(Theta, quantiles).
+#' or a string (in mode "Julia") containing the script of the Julia function
+#' simulatorQ(Theta, quantiles).
 #' In Julia mode, the name "simulatorQ" is mandatory.
-#' Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
-#' @param obj Objective function to minimize. Default : is directly computed from sumstats and simulatorQ.
+#' Theta is the parameter set for the simulations and
+#' quantiles are drawn in U(0,1).
+#' @param obj Objective function to minimize.
+#' Default : is directly computed from sumstats and simulatorQ.
 #' Either an R function of type objective(Theta, quantiles) (in mode "R")
-#' or a string (in mode "Julia") containing the script of the Julia function julia_obj(Theta, quantiles).
+#' or a string (in mode "Julia") containing the script of the Julia function
+#' julia_obj(Theta, quantiles).
 #' Warning : could be tricky if mode = "Julia" to call data.
 #' In Julia mode, the name "julia_obj" is mandatory.
-#' @param nsim Integer. Number of simulations to run for each step of the optimisation algorithm.
+#' @param nsim Integer. Number of simulations to run for each step
+#' of the optimization algorithm.
 #' Computation time grows linearly with this number. Default to 10.
 #' @param ninfer Integer. Number of independent inferences to run. Default to 1.
 #' @param lower 1D array. Lower bounds for parameters. Same length as upper.
 #' @param upper 1D array. Upper bounds for parameters. Same length as lower.
-#' @param Theta0 1D array. Initial values of the parameters. Default : mean(lower, upper).
-#' @param randomTheta0 Boolean. If True, Theta0 is randomly drawn between lower and upper bounds.
-#' @param mode String. "R" (default) or "Julia". See Readme.
-#' @param AD Boolean. Only in Julia mode, uses Automatic Differentiation with IPNewton method. Default to true.
-#' @param method String. In Julia mode, allows to choose the optimization method : "Brent", "IPNewton". Default : IPNewton.
-#' @param maxit Integer. Max number of iterations during optimization. Default to 1000.
-#' @param time_lim Float. Time limit in second for each inference. Default to no limit. Not available for R mode and Brent method in Julia mode.
-#' @param factr Float. In R-mode : control parameter for L-BFGS-B method in stats::optim. Default to 1e7.
-#' @param pgtol Float. In R-mode : control parameter for L-BFGS-B method in stats::optim. Default to 0.
-#' @param xtol Float. In Julia mode with IPNewton method : xtol option in Optim.Options. Default to 0.
-#' @param ftol Float. In Julia mode with IPNewton method : ftol option in Optim.Options. Default to 0.
-#' @param gtol Float. In Julia mode with IPNewton method : gtol option in Optim.Options. Default to 1e-8.
-#' @param reltol Float. In Julia mode with Brent method : reltol of Optim.optimize. Default is sqrt(.Machine$double.eps), about 1e-8.
-#' @param abstol Float. In Julia mode with Brent method : abstol of Optim.optimize. Default is .Machine$double.eps, about 1e-16.
+#' @param Theta0 1D array. Initial values of the parameters.
+#' Default : mean(lower, upper).
+#' @param randomTheta0 Boolean.
+#' If True, Theta0 is randomly drawn between lower and upper bounds.
+#' @param mode String. "R" (default) or "Julia". See README.
+#' @param AD Boolean.
+#' Only in Julia mode, uses Automatic Differentiation with IPNewton method.
+#' Default to true.
+#' @param method String.
+#' In Julia mode, allows to choose the optimization method :
+#' "Brent", "IPNewton". Default : IPNewton.
+#' @param maxit Integer. Max number of iterations during optimization.
+#' Default to 1000.
+#' @param time_lim Float. Time limit in second for each inference.
+#' Default to no limit. Not available for R mode and Brent method in Julia mode.
+#' @param factr Float.
+#' In R-mode : control parameter for L-BFGS-B method in stats::optim.
+#' Default to 1e7.
+#' @param pgtol Float.
+#' In R-mode : control parameter for L-BFGS-B method in stats::optim.
+#' Default to 0.
+#' @param xtol Float.
+#' In Julia mode with IPNewton method : xtol option in Optim.Options.
+#' Default to 0.
+#' @param ftol Float.
+#'In Julia mode with IPNewton method : ftol option in Optim.Options.
+#Default to 0.
+#' @param gtol Float.
+#' In Julia mode with IPNewton method : gtol option in Optim.Options.
+#' Default to 1e-8.
+#' @param reltol Float.
+#' In Julia mode with Brent method : reltol of Optim.optimize.
+#' Default is sqrt(.Machine$double.eps), about 1e-8.
+#' @param abstol Float.
+#' In Julia mode with Brent method : abstol of Optim.optimize.
+#' Default is .Machine$double.eps, about 1e-16.
 #' @param show_trace Boolean. If true, shows standard trace. Default to false.
-#' @param store_trace Boolean. If true, stores standard trace as an array of strings. Default to false. Not available for R mode.
-#' @param store_quantiles Boolean. If true, stores every quantiles used for inference, to reproduce the results. Default to false.
-#' @param par_names vector of names for parameters. Default is "par1", ..., "parn".
-#' @param load_julia Boolean. If true, run julia_load. It can take few seconds. Default to False.
+#' @param store_trace Boolean.
+#' If true, stores standard trace as an array of strings.
+#' Default to false. Not available for R mode.
+#' @param store_quantiles Boolean.
+#' If true, stores every quantiles used for inference, to reproduce the results.
+#'Default to false.
+#' @param par_names vector of names for parameters.
+#' Default is "par1", ..., "parn".
+#' @param load_julia Boolean. If true, run julia_load.
+#' It can take few seconds. Default to False.
 #'
-#' @return Object of class flimo_result (list) (converted from Julia object in Julia mode) containing every information about convergence results.
+#' @return Object of class flimo_result (list)
+#' (converted from Julia object in Julia mode) containing every information
+#' about convergence results.
 #'
 #' @examples
 #'data <- rep(100, 5)
@@ -218,7 +269,7 @@ flimoptim <- function(data, ndraw, sumstats, simulatorQ,
                    par_names = NULL,
                    load_julia = FALSE){
   if (length(mode) > 1){
-    mode = mode[1] #default is R
+    mode <- mode[1] #default is R
   }
   if (mode == "Julia"){
       flimoptim_Julia(data, ndraw, sumstats, simulatorQ,
@@ -246,7 +297,7 @@ flimoptim <- function(data, ndraw, sumstats, simulatorQ,
   }
   else {
     if (mode != "R"){
-      message("Default mode : full R optimisation")
+      message("Default mode : full R optimization")
     }
     flimoptim_R(data, ndraw, sumstats, simulatorQ,
                   obj = obj,
@@ -269,33 +320,50 @@ flimoptim <- function(data, ndraw, sumstats, simulatorQ,
 
 #' @title flimoptim_R
 #'
-#' @description Computes several parameter inferences with R optimizer (method L-BFGS-B).
+#' @description Computes several parameter inferences with R optimizer
+#' (method L-BFGS-B).
 #'
 #' @param data 1D array containing the observations.
-#' @param ndraw Integer. Number of random variables to draw for one simulation of the model.
-#' @param sumstats Summary statistics to measure distance between simulations and data.
-#' R function of type sumstats(simulations, data) where simulations : 2D array and data : 1D array.
+#' @param ndraw Integer. Number of random variables to draw
+#' for one simulation of the model.
+#' @param sumstats Summary statistics to measure distance
+#' between simulations and data.
+#' R function of type sumstats(simulations, data)
+#' where simulations : 2D array and data : 1D array.
 #' ncol(simulations) = length(data) mandatory.
-#' @param simulatorQ Simulator of the stochastic process with fixed quantiles (see Readme).
+#' @param simulatorQ Simulator of the stochastic process with fixed quantiles
+#' (see README).
 #  R function of type simulatorQ(Theta, quantiles)
-#' Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
-#' @param obj Objective function to minimize. Default : is directly computed from sumstats and simulatorQ.
+#' Theta is the parameter set for the simulations and
+#' quantiles are drawn in U(0,1).
+#' @param obj Objective function to minimize.
+#' Default : is directly computed from sumstats and simulatorQ.
 #' R function of type objective(Theta, quantiles)
-#' @param nsim Integer. Number of simulations to run for each step of the optimisation algorithm.
+#' @param nsim Integer. Number of simulations to run for each step
+#' of the optimization algorithm.
 #' Computation time grows linearly with this number. Default to 10.
 #' @param ninfer Integer. Number of independent inferences to run. Default to 1.
 #' @param lower 1D array. Lower bounds for parameters. Same length as upper.
 #' @param upper 1D array. Upper bounds for parameters. Same length as lower.
-#' @param Theta0 1D array. Initial values of the parameters. Default : mean(lower, upper).
-#' @param randomTheta0 Boolean. If True, Theta0 is randomly drawn between lower and upper bounds.
-#' @param maxit Integer. Max number of iterations during optimization. Default to 1000.
-#' @param factr Float. Control parameter for L-BFGS-B method in stats::optim. Default to 1e7.
-#' @param pgtol Float. Control parameter for L-BFGS-B method in stats::optim. Default to 0.
+#' @param Theta0 1D array. Initial values of the parameters.
+#' Default : mean(lower, upper).
+#' @param randomTheta0 Boolean.
+#' If True, Theta0 is randomly drawn between lower and upper bounds.
+#' @param maxit Integer. Max number of iterations during optimization.
+#' Default to 1000.
+#' @param factr Float. Control parameter for L-BFGS-B method in stats::optim.
+#'Default to 1e7.
+#' @param pgtol Float. Control parameter for L-BFGS-B method in stats::optim.
+#'Default to 0.
 #' @param show_trace Boolean. If true, shows standard trace. Default to false.
-#' @param store_quantiles Boolean. If true, stores every quantiles used for inference, to reproduce the results. Default to false.
-#' @param par_names vector of names for parameters. Default is "par1", ..., "parn".
+#' @param store_quantiles Boolean.
+#'If true, stores every quantiles used for inference, to reproduce the results.
+# Default to False.
+#' @param par_names vector of names for parameters.
+#' Default is "par1", ..., "parn".
 #'
-#' @return Object of class flimo_result (list) containing every information about convergence results.
+#' @return Object of class flimo_result (list) containing every information
+#' about convergence results.
 #'
 
 flimoptim_R <- function(data, ndraw, sumstats, simulatorQ,
@@ -323,7 +391,8 @@ flimoptim_R <- function(data, ndraw, sumstats, simulatorQ,
   converged <- rep(NA, ninfer)
   message <- rep(NA, ninfer)
   if (store_quantiles){
-    all_quantiles <- array(rep(NA, ninfer*nsim*ndraw), dim=c(ninfer, nsim, ndraw))
+    all_quantiles <- array(rep(NA, ninfer*nsim*ndraw),
+                          dim=c(ninfer, nsim, ndraw))
   }
   time_run <- rep(NA, ninfer)
 
@@ -340,7 +409,7 @@ flimoptim_R <- function(data, ndraw, sumstats, simulatorQ,
       }
     }
     if (randomTheta0){
-      Theta0 = runif(length(lower))*(upper-lower)+lower
+      Theta0 <- runif(length(lower))*(upper-lower)+lower
     }
 
     start_time <- Sys.time()
@@ -370,7 +439,7 @@ flimoptim_R <- function(data, ndraw, sumstats, simulatorQ,
   optim_result <- NULL
   optim_result$mode <- "R"
   optim_result$method <- "L-BFGS-B"
-  optim_result$AD <- F
+  optim_result$AD <- FALSE
   optim_result$minimizer <- minimizer
   optim_result$minimum <- minimum
   optim_result$converged <- converged
@@ -394,44 +463,74 @@ flimoptim_R <- function(data, ndraw, sumstats, simulatorQ,
 
 #' @title flimoptim_Julia
 #'
-#' @description Computes several parameter inferences with Julia optimizer and either IPNewton with or without Automatic Differentation or Brent method.
+#' @description Computes several parameter inferences with Julia optimizer and
+#' either IPNewton with or without Automatic Differentiation or Brent method.
 #'
 #' @param data 1D array containing the observations.
-#' @param ndraw Integer. Number of random variables to draw for one simulation of the model.
-#' @param sumstats Summary statistics to measure distance between simulations and data.
-#' String containing the script of the Julia function sumstats(simulations, data).
+#' @param ndraw Integer. Number of random variables to draw
+#' for one simulation of the model.
+#' @param sumstats Summary statistics to measure distance
+#' between simulations and data.
+#' String containing the script of the Julia function
+#' sumstats(simulations, data).
 #' The name "sumstats" is mandatory.
-#' @param simulatorQ Simulator of the stochastic process with fixed quantiles (see Readme).
-#  String containing the script of the Julia function simulatorQ(Theta, quantiles).
+#' @param simulatorQ Simulator of the stochastic process
+#' with fixed quantiles (see README).
+#  String containing the script of the Julia function
+#' simulatorQ(Theta, quantiles).
 #' The name "simulatorQ" is mandatory.
-#' Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
-#' @param julia_obj Objective function to minimize. Default : is directly computed from sumstats and simulatorQ.
-#' String containing the script of the Julia function julia_obj(Theta, quantiles).
+#' Theta is the parameter set for the simulations and
+#' quantiles are drawn in U(0,1).
+#' @param julia_obj Objective function to minimize.
+#' Default : is directly computed from sumstats and simulatorQ.
+#' String containing the script of the Julia function
+#' julia_obj(Theta, quantiles).
 #' Warning : can be tricky to call data.
 #' The name "julia_obj" is mandatory.
-#' @param nsim Integer. Number of simulations to run for each step of the optimisation algorithm.
+#' @param nsim Integer. Number of simulations to run for each step
+#' of the optimization algorithm.
 #' Computation time grows linearly with this number. Default to 10.
 #' @param ninfer Integer. Number of independent inferences to run. Default to 1.
 #' @param lower 1D array. Lower bounds for parameters. Same length as upper.
 #' @param upper 1D array. Upper bounds for parameters. Same length as lower.
-#' @param Theta0 1D array. Initial values of the parameters. Default : mean(lower, upper).
-#' @param randomTheta0 Boolean. If True, Theta0 is randomly drawn between lower and upper bounds.
-#' @param AD Boolean. Only in Julia mod, uses Automatic Differentiation with IPNewton method. Default to true.
-#' @param method String. Allows to choose the optimization method : "Brent", "IPNewton". Default : IPNewton.
-#' @param maxit Integer. Max number of iterations during optimization. Default to 1000.
-#' @param time_lim Float. Time limit in second for each inference. Default to no limit. Not available for Brent method.
-#' @param xtol Float. With IPNewton method : xtol option in Optim.Options. Default to 0.
-#' @param ftol Float. With IPNewton method : ftol option in Optim.Options. Default to 0.
-#' @param gtol Float. With IPNewton method : gtol option in Optim.Options. Default to 1e-8.
-#' @param reltol Float. With Brent method : reltol of Optim.optimize. Default is sqrt(.Machine$double.eps), about 1e-8.
-#' @param abstol Float. With Brent method : abstol of Optim.optimize. Default is .Machine$double.eps, about 1e-16.
+#' @param Theta0 1D array. Initial values of the parameters.
+#' Default : mean(lower, upper).
+#' @param randomTheta0 Boolean.
+#' If True, Theta0 is randomly drawn between lower and upper bounds.
+#' @param AD Boolean.
+#' Only in Julia mod, uses Automatic Differentiation with IPNewton method.
+#' Default to true.
+#' @param method String.
+#' Allows to choose the optimization method : "Brent", "IPNewton".
+#' Default : IPNewton.
+#' @param maxit Integer. Max number of iterations during optimization.
+#' Default to 1000.
+#' @param time_lim Float. Time limit in second for each inference.
+#' Default to no limit. Not available for Brent method.
+#' @param xtol Float. With IPNewton method : xtol option in Optim.Options.
+#' Default to 0.
+#' @param ftol Float. With IPNewton method : ftol option in Optim.Options.
+#' Default to 0.
+#' @param gtol Float. With IPNewton method : gtol option in Optim.Options.
+#' Default to 1e-8.
+#' @param reltol Float. With Brent method : reltol of Optim.optimize.
+#' Default is sqrt(.Machine$double.eps), about 1e-8.
+#' @param abstol Float. With Brent method : abstol of Optim.optimize.
+#' Default is .Machine$double.eps, about 1e-16.
 #' @param show_trace Boolean. If true, shows standard trace. Default to false.
-#' @param store_trace Boolean. If true, stores standard trace as an array of strings. Default to false. Not available for R mod.
-#' @param store_quantiles Boolean. If true, stores every quantiles used for inference, to reproduce the results. Default to false.
-#' @param par_names vector of names for parameters. Default is "par1", ..., "parn".
-#' @param load_julia Boolean. If true, run julia_load. It can take few seconds. Default to False.
+#' @param store_trace Boolean.
+#' If true, stores standard trace as an array of strings.
+#' Default to false. Not available for R mod.
+#' @param store_quantiles Boolean.
+#' If true, stores every quantiles used for inference, to reproduce the results.
+#' Default to false.
+#' @param par_names vector of names for parameters.
+#' Default is "par1", ..., "parn".
+#' @param load_julia Boolean. If true, run julia_load. It can take few seconds.
+#' Default to False.
 #'
-#' @return Object of class flimo_result (list) converted from Julia object containing every information about convergence results.
+#' @return Object of class flimo_result (list) converted from Julia object
+#' containing every information about convergence results.
 #'
 
 
@@ -508,7 +607,8 @@ flimoptim_Julia <- function(data, ndraw, sumstats, simulatorQ,
     juliaEval(paste0('julia_obj = nothing','\n', sumstats, '\n', simulatorQ))
   }
   else {
-    juliaEval(paste0(julia_obj, '\n', 'sumstats = nothing\nsimulatorQ = nothing'))
+    juliaEval(paste0(julia_obj,
+                    '\n', 'sumstats = nothing\nsimulatorQ = nothing'))
   }
 
   optim_result <- juliaGet(juliaEval("
@@ -544,9 +644,11 @@ flimoptim_Julia <- function(data, ndraw, sumstats, simulatorQ,
   class(optim_result) <- "flimo_result"
   optim_result$mode <- "Julia"
   optim_result$AD <- AD
-  if (is.null(par_names)) colnames(optim_result$minimizer) <- paste0("par", 1:length(lower))
+  if (is.null(par_names))
+    colnames(optim_result$minimizer) <- paste0("par", 1:length(lower))
   else colnames(optim_result$minimizer) <- par_names
-  names(optim_result)[names(optim_result) == "iteration_converged"] <- "iteration_limit_reached"
+  names(optim_result)[names(optim_result) == "iteration_converged"] <-
+    "iteration_limit_reached"
 
   optim_result
 }
@@ -557,16 +659,18 @@ flimoptim_Julia <- function(data, ndraw, sumstats, simulatorQ,
 #'
 #' @description Prints most important information about inference results.
 #'
-#' @param x Object of class flimo_result from any mod/method algorithm of the flimo package.
+#' @param x Object of class flimo_result from any mod/method algorithm
+#' of the flimo package.
 #' @param ... optional args for generic method
 #'
-#' @return String containing most important information about argument of class flimo_result.
+#' @return String containing most important information about argument
+#' of class flimo_result.
 #'
 #' @export
 #'
 
 print.flimo_result <- function(x, ...){
-  value <- 'Optimisation Result\n'
+  value <- 'optimization Result\n'
   value <- paste0(value, "Mode : ", x$mod,"\n")
   if (length(as.character(x$method)) == 1){
     value <- paste0(value, "method : ", as.character(x$method),"\n")
@@ -575,12 +679,16 @@ print.flimo_result <- function(x, ...){
     value <- paste0(value, "method : ", attr(x$method,"JLTYPE"),"\n")
   }
   value <- paste0(value, "Number of inferences : ", length(x$minimum),"\n")
-  value <- paste0(value, "Convergence : ", length(which(x$converged)),"/",length(x$minimum),"\n")
+  value <- paste0(value, "Convergence : ", length(which(x$converged)),"/",
+                  length(x$minimum),"\n")
   value <- paste0(value,"Mean of minimizer :\n")
   value <- paste0(value, paste(colMeans(x$minimizer), collapse = "    "),"\n")
   value <- paste0(value, "Best minimizer :\n")
-  value <- paste0(value, paste(x$minimizer[which(x$minimum == min(x$minimum))[1],], collapse = "    "))
-  value <- paste0(value, "\nReached minima : from ", min(x$minimum), " to ", max(x$minimum))
+  value <- paste0(value,
+                  paste(x$minimizer[which(x$minimum == min(x$minimum))[1],],
+                        collapse = "    "))
+  value <- paste0(value, "\nReached minima : from ", min(x$minimum), " to ",
+                  max(x$minimum))
   value <- paste0(value, "\nMedian time by inference ", median(x$time_run))
   cat(value)
   value
@@ -590,10 +698,12 @@ print.flimo_result <- function(x, ...){
 #'
 #' @description Most important information about inference results.
 #'
-#' @param object Object of class flimo_result from any mode/method algorithm of the Jflimo package.
+#' @param object Object of class flimo_result from any mode/method algorithm
+#' of the Jflimo package.
 #' @param ... optional args for generic method summary
 #'
-#' @return List containing most important information about argument of class flimo_result.
+#' @return List containing most important information about argument
+#' of class flimo_result.
 
 #' @export
 #'
@@ -627,12 +737,14 @@ summary.flimo_result <- function(object, ...){
 #' @title check_simulator
 #'
 #' @description Run simulations to catch random variations.
-#' Warning : does not check it formaly.
+#' Warning : does not check it formally.
 #' Warning : does not check if quantiles are used several times.
 #'
 #' @param simulatorQ Function of type simulatorQ(Theta, quantiles)
-#' where Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
-#' @param ndraw Integer. Number of random variables to draw for one simulation of the model.
+#' where Theta is the parameter set for the simulations and
+#' quantiles are drawn in U(0,1).
+#' @param ndraw Integer. Number of random variables to draw
+#' for one simulation of the model.
 #' @param Theta_lower 1D numeric array. Lower bounds of Theta parameters.
 #' @param Theta_upper 1D numeric array. Upper bounds of Theta parameters.
 #' @param ntheta Integer. Number of Theta parameters to test.
@@ -658,7 +770,7 @@ check_simulator <- function(simulatorQ, ndraw, Theta_lower = 0, Theta_upper = 1,
   }
   if (nruns <= 1){
     message("check_simulator is useless with nruns <= 1. nruns set to 2.")
-    nruns = 2
+    nruns <- 2
   }
   for (i in 1:ntheta){
     Theta <- runif(length(Theta_lower))*(Theta_upper-Theta_lower)+Theta_lower
@@ -670,7 +782,8 @@ check_simulator <- function(simulatorQ, ndraw, Theta_lower = 0, Theta_upper = 1,
       message("This simulator is not conceived to work with quantiles")
       return(FALSE)
     })
-    tryCatch({if (!all(apply(simulations, 2, function(x) length(unique(x)) == 1))){
+    tryCatch({if (!all(apply(simulations, 2, function(x)
+      length(unique(x)) == 1))){
       return(FALSE)
     }},error = function(e){
       return(FALSE)
@@ -683,17 +796,24 @@ check_simulator <- function(simulatorQ, ndraw, Theta_lower = 0, Theta_upper = 1,
 
 #' @title plot.flimo_result
 #'
-#' @description Shows the plots for most important inference results. Default only shows normalized boxplots for each infered parameter.
+#' @description Shows the plots for most important inference results.
+#' Default only shows normalized boxplots for each inferred parameter.
 #'
 #' @param x Object of class flimo_result.
 #' @param y unused generic argument.
 #' @param ... optional args for generic method
 #' @param bins Integer. Number of bins if hist is True.
-#' @param hist Boolean. If True, plots the histogram of each infered parameter. Default to false.
-#' @param par_minimum Boolean. If True, plots each infered parameter by reached minimum. Default to false.
-#' @param pairwise_par Boolean. If True, plots each pairs of infered parameters. Default to false.
-#' @param boxplot Boolean. If True, plots the boxplots of each infered parameter scaled by their mean. Default to true.
-#' @param par_names Vector of names for parameters. Default is "par1", ..., "parn".
+#' @param hist Boolean. If True, plots the histogram of each inferred parameter.
+#' Default to false.
+#' @param par_minimum Boolean.
+#' If True, plots each inferred parameter by reached minimum. Default to false.
+#' @param pairwise_par Boolean.
+#' If True, plots each pairs of inferred parameters.Default to false.
+#' @param boxplot Boolean.
+#' If True, plots the boxplots of each inferred parameter scaled by their mean.
+#' Default to true.
+#' @param par_names Vector of names for parameters.
+#' Default is "par1", ..., "parn".
 #'
 #' @return Nothing. Prints the asked ggplot objects.
 #'
@@ -713,19 +833,20 @@ plot.flimo_result <- function(x, y, ...,
   npar <- ncol(x$minimizer)
 
   for (par in 1:npar){
-    if (hist){ #Histogram for each infered parameter
+    if (hist){ #Histogram for each inferred parameter
       print(ggplot2::ggplot()+
               geom_histogram(aes(x$minimizer[,par]), bins = bins)+
               labs(x = paste0("parameter ", par))+
-              ggtitle(paste0("Histogram of infered parameter ", par)))
+              ggtitle(paste0("Histogram of inferred parameter ", par)))
     }
 
-    if (par_minimum){#Plot infered par = f(minimum)
+    if (par_minimum){#Plot inferred par = f(minimum)
       print(ggplot2::ggplot()+
               geom_point(aes(x$minimizer[,par], x$minimum))+
               scale_y_log10()+
               labs(x = paste0("parameter ", par), y = "reached minimum")+
-              ggtitle(paste0("Infered parameter ", par, " by reached minimum")))
+              ggtitle(paste0("inferred parameter ", par,
+                             " by reached minimum")))
     }
 
     if (pairwise_par){ #Plot par1 = f(par2)
@@ -733,7 +854,8 @@ plot.flimo_result <- function(x, y, ...,
         for (par2 in (par+1):npar){
           print(ggplot2::ggplot()+
                   geom_point(aes(x$minimizer[,par], x$minimizer[,par2]))+
-                  labs(x = paste0("Parameter ", par), y = paste0("Parameter ", par2))+
+                  labs(x = paste0("Parameter ", par),
+                       y = paste0("Parameter ", par2))+
                   ggtitle(paste0("Parameter ", par2, " by parameter ", par)))
         }
       }
@@ -745,12 +867,13 @@ plot.flimo_result <- function(x, y, ...,
     else colnames(aux) <- par_names
     aux <- stack(aux)
     for (par in unique(aux$ind)){
-      aux[aux$ind == par,]$values <- aux[aux$ind == par,]$values/mean(aux[aux$ind == par,]$values)
+      aux[aux$ind == par,]$values <-
+        aux[aux$ind == par,]$values/mean(aux[aux$ind == par,]$values)
     }
     print(ggplot2::ggplot(aux)+
             geom_boxplot(aes(x = ind, y = values))+
             labs(x = "Parameters", y = "Value/mean(Value)")+
-            ggtitle(paste0("Normalized boxplots\nfor each infered parameter")))
+            ggtitle(paste0("Normalized boxplots\nfor each inferred parameter")))
   }
 }
 
@@ -760,24 +883,33 @@ plot.flimo_result <- function(x, y, ...,
 #'
 #' @description Plot of objective = f(theta_index).
 #'
-#' @param ndraw Integer. Number of random variables to draw for one simulation of the model.
-#' @param nsim Integer. Number of simulations to run for each step of the optimisation algorithm.
+#' @param ndraw Integer.Number of random variables to draw
+#' for one simulation of the model.
+#' @param nsim Integer. Number of simulations to run for each step
+#' of the optimization algorithm.
 #' Computation time grows linearly with this number. Default to 10.
 #' @param data 1D array containing the observations.
-#' @param sumstats Function computing the distance between simulations and data of form sumstats(simulations, data) where simulations : 2D array and data : 1D array.
+#' @param sumstats Function computing the distance
+#' between simulations and data of form sumstats(simulations, data)
+#' where simulations : 2D array and data : 1D array.
 #' ncol(simulations) = length(data) mandatory.
 #' @param simulatorQ Function of type simulatorQ(Theta, quantiles)
-#' where Theta is the parameter set for the simulations and quantiles are drawn in U(0,1).
+#' where Theta is the parameter set for the simulations and
+#' quantiles are drawn in U(0,1).
 #' @param quantiles 2D array containing values following U(0,1).
 #' Row number = number of simulations.
 #' Column number = number of random variables to draw in one simulation.
-#' @param obj objective function of type objective(Theta). Default : directly computed with "sumstats" and "simulatorQ".
+#' @param obj objective function of type objective(Theta).
+#' Default : directly computed with "sumstats" and "simulatorQ".
 #' @param index Integer. Index of the moving parameter.
 #' @param other_param Other parameters of the model. If NULL : assume 1D-model.
 #' If numeric : 2D-model, one curve.
-#' If 1D-array and dim2 is True (default) : 2D-model, one curve by value in other_param.
-#' If 1D-array and dim2 is False or 2D-array : (n>2)D-model, one curve by row in other_param.
-#' If your model has n>2 dimensions, you should define other_param as a matrix even if
+#' If 1D-array and dim2 is True (default) :
+#' 2D-model, one curve by value in other_param.
+#' If 1D-array and dim2 is False or 2D-array : (n>2)D-model,
+#' one curve by row in other_param.
+#' If your model has n>2 dimensions,
+#' you should define other_param as a matrix even if
 #' you have only one parameter set to test
 #' (with as.matrix(t(vect_param)) where vect_param is a 1D-array).
 #' @param lower Numeric. Lower value of the plot.
@@ -827,7 +959,8 @@ plot_objective <- function(ndraw, nsim, data, sumstats, simulatorQ,
     else {
       q <- quantiles
     }
-    intern_obj <- function(Theta) flimobjective(Theta, q, data, sumstats, simulatorQ)
+    intern_obj <- function(Theta) flimobjective(Theta, q, data,
+                                                sumstats, simulatorQ)
   }
   else {
     intern_obj <- obj
@@ -851,14 +984,18 @@ plot_objective <- function(ndraw, nsim, data, sumstats, simulatorQ,
     else{
       other_param <- as.matrix(t(other_param)) #convert to 1*length matrix
 
-      return(plot_objectivenD(intern_obj, index, other_param, lower = lower, upper = upper,
+      return(plot_objectivenD(intern_obj, index, other_param,
+                              lower = lower,
+                              upper = upper,
                               visualize_min = visualize_min,
                               plot_legend = plot_legend,
                               add_to_plot = add_to_plot))
     }
   }
   else {
-    return(plot_objectivenD(intern_obj, index, other_param, lower = lower, upper = upper,
+    return(plot_objectivenD(intern_obj, index, other_param,
+                            lower = lower,
+                            upper = upper,
                             visualize_min = visualize_min,
                             plot_legend = plot_legend,
                             add_to_plot = add_to_plot))
@@ -939,7 +1076,8 @@ plot_objectivenD <- function(obj,
       Theta[1:(index-1)] <- other_par[1:(index-1)]
     }
     if (index < length(other_par)+1){
-      Theta[(index+1):(length(other_par)+1)] <- other_par[index:length(other_par)]
+      Theta[(index+1):(length(other_par)+1)] <-
+        other_par[index:length(other_par)]
     }
     obj(Theta)
   }
@@ -984,7 +1122,8 @@ plot_objectivenD <- function(obj,
          color = "Param.")
 
   if (is.null(add_to_plot)){
-    p <- p + ggtitle(paste("Objective function to minimize by parameter", index))+
+    p <- p +
+      ggtitle(paste("Objective function to minimize by parameter",index))+
       labs(x = paste0("theta_", index), y = "objective value")
   }
 
